==> KleckFiles(3.03.1).zip: KleckFiles/report/reportdata_keys.js <==
// pDate = date published in KR
// wDate = actual date released on web

var reportdata_keys = [
{type:"keys",
 tab: "Intro",
 title: "The Keys to the Kingdom of Heaven",
 desc: "This morning I woke up and the Lord said, Robert you need to explain the Keys to Heaven"
   +" using the film 'Ready Player One'. Wow. This film is Jonathan Kleck's message on the big screen."
   +" In the film a great prize awaited anyone who could crack the code - Find the 3 Keys hidden throughout the virtual world.",
 image: "report/media/keys/ReadyPlayerOne.jpg|",
 bible1: "mat 16:18|Mat 16:18-19"
   +"|<sup>18</sup> And I say also unto thee, That thou art Peter, and upon this rock I will build my church; and the gates of hell shall not prevail against it."
   +"|<sup>19</sup> And I will give unto thee <u>the keys of the kingdom of heaven</u>: and whatsoever thou shalt bind on earth shall be bound in heaven: and whatsoever thou shalt loose on earth shall be loosed in heaven.",
 image2: "report/media/keys/stpeter.jpg|tools.html?AoP%2038:5&mark|Acts of Peter 38:5"
   +"|Peter, the man Jesus gave the keys of heaven to, and told to 'feed my sheep', "
   +"asked specifically to be crucified upside down when sentenced to death by Agrippa."
   +'<br>Do you know why? Well worth reading Chapters 37-38 (<a href="html/kjv/151103_aop.mp3" target="audioWin">☊ audio available</a> - read by Jonathan).'
 
},	
	
{type:"keys",
 tab: "⚿ Backwards",
 title: "Ready Player One? Key#1, first Clue : '<b>Backwards</b>'",
 desc: "How many times has Jonathan showed us this. The truth is inverted in this world. To SEE the truth you need to turn it upside down. Jesus is the truth."
   +" St Peter asked to be crucified upside down, then told us plainly on that inverted cross 'you will never see the kingdom unless you flip the world'.",

 image0: 'report/media/keys/backwards.jpg|https://youtu.be/ceePPKao7is|Video: In the movie Parzival finds the first clue: Backwards.'
  +'|Oh just like Jonathan keeps saying - "Turn it upside down: %100 No Lying (truth)"',

 bible2: "Matt 16:18|Matthew 16:18-19"
  +"|<sup>18</sup> And I say also unto thee, That thou art Peter, and upon this rock I will build my church; and the gates of hell shall not prevail against it."
  +"|<sup>19</sup> And I will give unto thee the keys of the kingdom of heaven: and whatsoever thou shalt bind on earth shall be bound in heaven: and whatsoever thou shalt loose on earth shall be loosed in heaven.",
 bible3: "AoP%2038:5&mark|Acts of Peter 38:5"
  +"|<sup>5</sup> Concerning which the Lord saith in a mystery: Unless ye make the things of the right hand as those of the left, and those of the left as those of the right, and those that are above as those below, and those that are behind as those that are before, ye shall not have knowedge of the kingdom.",
 bible4: "Isaiah |Isaiah 29:15-16"
  +"|<sup>15</sup> Woe unto them that seek deep to hide their counsel from the Lord, and their works are in the dark, and they say, Who seeth us? and who knoweth us?"
  +"|<sup>16</sup> Surely your turning of things upside down shall be esteemed as the potter's clay: for shall the work say of him that made it, He made me not? or shall the thing framed say of him that framed it, He had no understanding?",

 image2: 'report/media/keys/snare.jpg|151103|Video: Jesus Christ is "the snare" that turns the world upside down'
  +'|Trying to think of the best Kleck video. This is a favorite, but really almost every video testimony deals with the upside down paradigm.',

 image3: 'report/media/keys/jkreversal.jpg|180721-02|Video: Acts of Peter and MORE Miracles'
   +'|Jesus talking to Peter said on this rock I will build my church. Here Jonanthan takes us into the Acts of Peter, where Peter tells us we need to flip the world to see the truth. This is what being on the Rock is all about.'
},
	
{type:"keys",
 tab: "⚿ Regrets",
 title: "Ready Player One? The second key is 'Regrets'",
 desc: 'In the film, the second clue/key is about saying words unspoken, regrets.'
  +' To find the second clue the player needed to go into the Shining movie, avoiding room 237, '
  +' and face your first love and say those words you should have said.',
 desc2: 'Jonathan will show you the proof in scripture.'
  + ' That we are Els childen who took Lucifers bait and got trapped in host body system.'
  + ' The important thing now is face our good Father and say sorry, I broke you commands and turned away from you.',
 image0: "report/media/keys/shining.jpg|https://youtu.be/Vmd4E3WNg-w|Video: The Shinning. The key to room 237. Solving the 2nd puzzle.",
 image1: "211130-02|211130-02|Video: These Scriptures will explain it all"
   +"|In my opinion this is the most important Kleck video to watch over and over and understand."
   +" For if you do not know your true identity hidden in Jesus, how can you say really say sorry and be redeemed?"
   +" Reconciliation means the restoration of friendly relations. I need to know why I was God's enemy, what I'd done wrong, before I could properly say sorry.",
 
 bible1: "psalm 82:6|Psalm 82:6-8"
   + "|<sup>6</sup> I have said, Ye are gods(h430); and all of you are children of the most High."
 	+ "|<sup>7</sup> But ye shall die like men, and fall like one of the princes."
 	+ "|<sup>8</sup> Arise, O God(h430), judge the earth: for thou shalt inherit all nations."
   + "<br><br>Note that here <a href='https://biblehub.com/hebrew/430.htm' target='_blank'>Hebrew word 430 Elohim</a> means angels, magistrates OF the supreme God. It is NOT the Lord God.",
 bible2: "2pe 3:8|2 Peter 3:8-10" 
   + "|<sup>8</sup> But, beloved, be not ignorant of this one thing, that one day is with the Lord as a thousand years, and a thousand years as one day."
   + "|<sup>9</sup> The Lord is not slack concerning his promise, as some men count slackness; but is longsuffering to us-ward, not willing that any should perish, but that all should come to repentance."
   + "|<sup>10</sup> But the day of the Lord will come as a thief in the night; in the which the heavens shall pass away with a great noise, and the elements shall melt with fervent heat, the earth also and the works that are therein shall be burned up."
},
	
{type:"keys",
 tab: "⚿ Surrender",
 title: "Ready Player One? The third key is 'Surrender'",
 desc: "In the movie our hero Parzival learns how to beat the game. You stop trying to win. You listen to the creator. You search every dark corner. Finally he finds an invisible small dot (an easter egg hidden by the orginal creator): The creators name.",
 desc2: "Jonathan was given a clear message. Give up. Surrender to Fathers will. You have actually been a slave to the devil and wear his skins and host body. Stop fighting, you only fight with yourself.",
 desc3: "The idea of being caught upside down in a snare is perfect. The more you struggle the tighter the slipknot gets. The worse your condition.",
 image0: "report/media/keys/surrender1.jpg|https://youtu.be/V5e6w5EFmEg"
   +"|Video: Parzival stops trying to win the game and plays by the creators rules."
   +"|Interesting to note that the bad guy arrives holding his team buddy hostage tied up in a squid."
   +"<br>If you want more RPO click here to see <a href='https://youtu.be/kSzRvnby7mg' target='_blank'>part 2</a> and <a href='https://youtu.be/sCLe3hRyXRU' target='_blank'>part 3</a>.",
 
 image1: "report/media/keys/systemofcontrol.jpg"
  +"|index.html?2&14"
  +"|Video Series: Intro for New Subs - SYSTEM OF CONTROL"
  +"|This series is a good starting place. The first video gives you great concepts to grab hold of."
 
},
{type:"keys",
 tab: "The End",
 title: "The End",
 desc: ""
  +" Conversion is discombobulating. Some say like scales falling from the eyes."
  +" To have your core belief system flipped is a freak out."
  +" But.. being on the Rock is everything. It is the greatest treasure."
  +" To know the Lord came into a world that hated him, that brutally killed him in flesh. He did all that so that we might have life again.", 
 
 desc1: "See the word 'conversion' below? Greek word 1995. It means 'a turning about', 'a turning (to God)', 'reversion, i.e. Morally, revolution -- conversion'."
 +" Cause we turned away from our Father, took Lucifer's bait and got caught a host body snare system of control. Here the only outcome is death. We are walking dead until we get converted."
 +" But i'm rattling on and Jonathan is an authorized teacher. The end is here. Best thing I found is asking for truth, bible, be God centered no longer man centred. "
 +" From here man's kingdom completely unravels. Invest in an everlasting kingdom and a kind and good father. God bless you in your search -- Robert Chandler (<a href='http://www.cleckfiles.com' target='_blank'>KleckFiles.com</a>)", 
 
 bible1: "act 15:3|Acts 15:3"
 +"|<sup>3</sup> And being brought on their way by the church, they passed through Phenice and Samaria, declaring the <a href='https://biblehub.com/greek/1995.htm' target='_blank'>conversion(g1995)</a> of the Gentiles: and they caused great joy unto all the brethren."
 
 
 
}
	
	
	
];

==> KleckFiles(5.80.00).zip: KleckFiles/report/reportdata_keys.js <==
// pDate = date published in KR
// wDate = actual date released on web

var reportdata_keys = [
{type:"keys",
 tab: "Intro",
 title: "The Keys to the Kingdom of Heaven",
 desc: "This morning I woke up and the Lord said, Robert you need to explain the Keys to Heaven"
   +" using the film 'Ready Player One'. Wow. This film is Jonathan Kleck's message on the big screen."
   +" In the film a great prize awaited anyone who could crack the code - Find the 3 Keys hidden throughout the virtual world.",
 image: "report/media/keys/ReadyPlayerOne.jpg|",
 bible1: "mat 16:18|Mat 16:18-19"
   +"|<sup>18</sup> And I say also unto thee, That thou art Peter, and upon this rock I will build my church; and the gates of hell shall not prevail against it."
   +"|<sup>19</sup> And I will give unto thee <u>the keys of the kingdom of heaven</u>: and whatsoever thou shalt bind on earth shall be bound in heaven: and whatsoever thou shalt loose on earth shall be loosed in heaven.",
 image2: "report/media/keys/stpeter.jpg|tools.html?AoP%2038:5&mark|Acts of Peter 38:5"
   +"|Peter, the man Jesus gave the keys of heaven to, and told to 'feed my sheep', "
   +"asked specifically to be crucified upside down when sentenced to death by Agrippa."
   +'<br>Do you know why? Well worth reading Chapters 37-38 (<a href="html/kjv/151103_aop.mp3" target="audioWin">☊ audio available</a> - read by Jonathan).'
 
},	
	
{type:"keys",
 tab: "⚿ Backwards",
 title: "Ready Player One? Key#1, first Clue : '<b>Backwards</b>'",
 desc: "How many times has Jonathan showed us this. The truth is inverted in this world. To SEE the truth you need to turn it upside down. Jesus is the truth."
   +" St Peter asked to be crucified upside down, then told us plainly on that inverted cross 'you will never see the kingdom unless you flip the world'.",

 image0: 'report/media/keys/backwards.jpg|https://youtu.be/ceePPKao7is|Video: In the movie Parzival finds the first clue: Backwards.'
  +'|Oh just like Jonathan keeps saying - "Turn it upside down: %100 No Lying (truth)"',

 bible2: "Matt 16:18|Matthew 16:18-19"
  +"|<sup>18</sup> And I say also unto thee, That thou art Peter, and upon this rock I will build my church; and the gates of hell shall not prevail against it."
  +"|<sup>19</sup> And I will give unto thee the keys of the kingdom of heaven: and whatsoever thou shalt bind on earth shall be bound in heaven: and whatsoever thou shalt loose on earth shall be loosed in heaven.",
 bible3: "AoP%2038:5&mark|Acts of Peter 38:5"
  +"|<sup>5</sup> Concerning which the Lord saith in a mystery: Unless ye make the things of the right hand as those of the left, and those of the left as those of the right, and those that are above as those below, and those that are behind as those that are before, ye shall not have knowedge of the kingdom.",
 bible4: "Isaiah |Isaiah 29:15-16"
  +"|<sup>15</sup> Woe unto them that seek deep to hide their counsel from the Lord, and their works are in the dark, and they say, Who seeth us? and who knoweth us?"
  +"|<sup>16</sup> Surely your turning of things upside down shall be esteemed as the potter's clay: for shall the work say of him that made it, He made me not? or shall the thing framed say of him that framed it, He had no understanding?",

 image2: 'report/media/keys/snare.jpg|151103|Video: Jesus Christ is "the snare" that turns the world upside down'
  +'|Trying to think of the best Kleck video. This is a favorite, but really almost every video testimony deals with the upside down paradigm.',

 image3: 'report/media/keys/jkreversal.jpg|180721-02|Video: Acts of Peter and MORE Miracles'
   +'|Jesus talking to Peter said on this rock I will build my church. Here Jonanthan takes us into the Acts of Peter, where Peter tells us we need to flip the world to see the truth. This is what being on the Rock is all about.'
},
	
{type:"keys",
 tab: "⚿ Regrets",
 title: "Ready Player One? The second key is 'Regrets'",
 desc: 'In the film, the second clue/key is about saying words unspoken, regrets.'
  +' To find the second clue the player needed to go into the Shining movie, avoiding room 237, '
  +' and face your first love and say those words you should have said.',
 desc2: 'Jonathan will show you the proof in scripture.'
  + ' That we are Els childen who took Lucifers bait and got trapped in host body system.'
  + ' The important thing now is face our good Father and say sorry, I broke you commands and turned away from you.',
 image0: "report/media/keys/shining.jpg|https://youtu.be/Vmd4E3WNg-w|Video: The Shinning. The key to room 237. Solving the 2nd puzzle.",
 image1: "211130-02|211130-02|Video: These Scriptures will explain it all"
   +"|In my opinion this is the most important Kleck video to watch over and over and understand."
   +" For if you do not know your true identity hidden in Jesus, how can you say really say sorry and be redeemed?"
   +" Reconciliation means the restoration of friendly relations. I need to know why I was God's enemy, what I'd done wrong, before I could properly say sorry.",
 
 bible1: "psalm 82:6|Psalm 82:6-8"
   + "|<sup>6</sup> I have said, Ye are gods(h430); and all of you are children of the most High."
 	+ "|<sup>7</sup> But ye shall die like men, and fall like one of the princes."
 	+ "|<sup>8</sup> Arise, O God(h430), judge the earth: for thou shalt inherit all nations."
   + "<br><br>Note that here <a href='https://biblehub.com/hebrew/430.htm' target='_blank'>Hebrew word 430 Elohim</a> means angels, magistrates OF the supreme God. It is NOT the Lord God.",
 bible2: "2pe 3:8|2 Peter 3:8-10" 
   + "|<sup>8</sup> But, beloved, be not ignorant of this one thing, that one day is with the Lord as a thousand years, and a thousand years as one day."
   + "|<sup>9</sup> The Lord is not slack concerning his promise, as some men count slackness; but is longsuffering to us-ward, not willing that any should perish, but that all should come to repentance."
   + "|<sup>10</sup> But the day of the Lord will come as a thief in the night; in the which the heavens shall pass away with a great noise, and the elements shall melt with fervent heat, the earth also and the works that are therein shall be burned up."
},
	
{type:"keys",
 tab: "⚿ Surrender",
 title: "Ready Player One? The third key is 'Surrender'",
 desc: "In the movie our hero Parzival learns how to beat the game. You stop trying to win. You listen to the creator. You search every dark corner. Finally he finds an invisible small dot (an easter egg hidden by the orginal creator): The creators name.",
 desc2: "Jonathan was given a clear message. Give up. Surrender to Fathers will. You have actually been a slave to the devil and wear his skins and host body. Stop fighting, you only fight with yourself.",
 desc3: "The idea of being caught upside down in a snare is perfect. The more you struggle the tighter the slipknot gets. The worse your condition.",
 image0: "report/media/keys/surrender1.jpg|https://youtu.be/V5e6w5EFmEg"
   +"|Video: Parzival stops trying to win the game and plays by the creators rules."
   +"|Interesting to note that the bad guy arrives holding his team buddy hostage tied up in a squid."
   +"<br>If you want more RPO click here to see <a href='https://youtu.be/kSzRvnby7mg' target='_blank'>part 2</a> and <a href='https://youtu.be/sCLe3hRyXRU' target='_blank'>part 3</a>.",
 
 image1: "report/media/keys/systemofcontrol.jpg"
  +"|index.html?2&14"
  +"|Video Series: Intro for New Subs - SYSTEM OF CONTROL"
  +"|This series is a good starting place. The first video gives you great concepts to grab hold of."
 
},
{type:"keys",
 tab: "The End",
 title: "The End",
 desc: ""
  +" Conversion is discombobulating. Some say like scales falling from the eyes."
  +" To have your core belief system flipped is a freak out."
  +" But.. being on the Rock is everything. It is the greatest treasure."
  +" To know the Lord came into a world that hated him, that brutally killed him in flesh. He did all that so that we might have life again.", 
 
 desc1: "See the word 'conversion' below? Greek word 1995. It means 'a turning about', 'a turning (to God)', 'reversion, i.e. Morally, revolution -- conversion'."
 +" Cause we turned away from our Father, took Lucifer's bait and got caught a host body snare system of control. Here the only outcome is death. We are walking dead until we get converted."
 +" But i'm rattling on and Jonathan is an authorized teacher. The end is here. Best thing I found is asking for truth, bible, be God centered no longer man centred. "
 +" From here man's kingdom completely unravels. Invest in an everlasting kingdom and a kind and good father. God bless you in your search -- Robert Chandler (<a href='http://www.kleckfiles.com' target='_blank'>KleckFiles.com</a>)", 
 
 bible1: "act 15:3|Acts 15:3"
 +"|<sup>3</sup> And being brought on their way by the church, they passed through Phenice and Samaria, declaring the <a href='https://biblehub.com/greek/1995.htm' target='_blank'>conversion(g1995)</a> of the Gentiles: and they caused great joy unto all the brethren."
 
 
 
}
	
	
	
];
